@@ -4,4 +4,4 @@ mod bindings {
     include!(concat!(env!("OUT_DIR"), "/bindings.rs"));
 }
 
-pub use bindings::{umm_init, umm_malloc, umm_free, umm_calloc, umm_realloc};
\ No newline at end of file
+pub use bindings::{umm_init, umm_init_heap, umm_malloc, umm_free, umm_calloc, umm_realloc};
