@@ -9,7 +9,6 @@
 #define UMM_MALLOC_H
 
 #include <stdint.h>
-#include <stddef.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -17,11 +16,13 @@ extern "C" {
 
 /* ------------------------------------------------------------------------ */
 
-extern void  umm_init( void* heap_addr, size_t heap_size );
-extern void *umm_malloc( size_t size );
-extern void *umm_calloc( size_t num, size_t size );
-extern void *umm_realloc( void *ptr, size_t size );
-extern void  umm_free( void *ptr );
+extern void  umm_init_heap(void *ptr, size_t size);
+extern void  umm_init(void);
+
+extern void *umm_malloc(size_t size);
+extern void *umm_calloc(size_t num, size_t size);
+extern void *umm_realloc(void *ptr, size_t size);
+extern void  umm_free(void *ptr);
 
 /* ------------------------------------------------------------------------ */
 
